@@ -1,13 +1,8 @@
-"""API permission classes."""
-
 from django.conf import settings
-
 from rest_framework.permissions import BasePermission
 
 
-__all__ = [
-    "BlockSchemaAccess",
-]
+__all__ = ["BlockSchemaAccess"]
 
 
 class BlockSchemaAccess(BasePermission):
